#include <QPainter>
#include <QComboBox>
#include <QDebug>
#include <QTableView>
#include "departdelegate.h"

departDelegate::departDelegate(QObject *parent) : QStyledItemDelegate(parent)
{
    // créer les icônes
    busPixmap = new QPixmap(":/images/bus.svg");
    trainPixmap = new QPixmap(":/images/train.svg");
    tgvPixmap = new QPixmap(":/images/tgv.png");
}

departDelegate::~departDelegate()
{
    delete busPixmap;
    delete trainPixmap;
    delete tgvPixmap;
}

void departDelegate::paint ( QPainter * painter, const QStyleOptionViewItem  & option, const QModelIndex & index ) const
{
    QStyleOptionViewItem opt;
    QString gares,typeTransport;
    QStringList listeGares;
    QPixmap pixmap;
    QRect rect2(option.rect.x(),option.rect.y(),option.rect.width(),option.rect.height());
    int x,y,h;

    switch (index.column())
    {
    case 0:
        typeTransport = index.model()->data(index,Qt::DisplayRole).toString();       
        x = option.rect.x();
        y = option.rect.y();
        h = option.rect.height();
        if (typeTransport.startsWith("Car", Qt::CaseInsensitive))
            painter->drawPixmap(x,y,ICON_WIDTH,h,busPixmap->scaledToWidth(ICON_WIDTH));
        else if (typeTransport.contains("tgv",Qt::CaseInsensitive))
            painter->drawPixmap(x,y,ICON_WIDTH,h,tgvPixmap->scaledToWidth(ICON_WIDTH));
        else            
            painter->drawPixmap(x,y,ICON_WIDTH,h,trainPixmap->scaledToWidth(ICON_WIDTH));

        rect2.moveLeft(opt.rect.x() + ICON_WIDTH);
        painter->drawText(rect2,Qt::AlignLeft | Qt::AlignVCenter,typeTransport);
        break;
    case 3:
        opt = option;
        gares = index.model()->data(index,Qt::DisplayRole).toString();
        listeGares = gares.split(',');
        opt.displayAlignment = Qt::AlignCenter;
        if (listeGares.size() > 0)
        {
            painter->drawText(opt.rect,Qt::AlignCenter,listeGares.at(0));
        }
        break;
    default:
        QStyledItemDelegate::paint(painter,option,index);
    }

}

QSize departDelegate::sizeHint ( const QStyleOptionViewItem  & option, const QModelIndex & index ) const
{
    QString gares;
    QStringList listeGares;
    QString typeTransport;
    QSize size;
    int width;

    switch (index.column())
    {
    case 0:
        width = ICON_WIDTH + QStyledItemDelegate::sizeHint(option,index).width();
        size = QSize(width,option.rect.height());
        break;
    case 3:        
        gares = index.model()->data(index,Qt::DisplayRole).toString();
        listeGares = gares.split(',');
        if (listeGares.size() > 0)
        {
            size = QSize(300,50); //rect.size(); // faudrait voir à corriger ça quand même ...
        }
        else
            size = QStyledItemDelegate::sizeHint(option,index);
        break;
     default:
        size = QStyledItemDelegate::sizeHint(option,index);
    }
    return size;
}

QWidget *departDelegate::createEditor(QWidget *parent, const QStyleOptionViewItem &option, const QModelIndex &index) const
{    
    if (index.column()==3)
    {
        QComboBox *combo = new QComboBox(parent);
        return combo;
    }
    else
        return QStyledItemDelegate::createEditor(parent,option,index);

}

void departDelegate::setEditorData(QWidget *editor, const QModelIndex &index) const
{
    if (index.column()==3)
    {
        QComboBox *combo = static_cast<QComboBox*>(editor);
        QString gares = index.model()->data(index,Qt::DisplayRole).toString();
        QStringList listeGares = gares.split(',');
        combo->addItems(listeGares);
    }
    else
        QStyledItemDelegate::setEditorData(editor,index);
}
